"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.separate = exports.parseYaml = exports.parse = exports.compileMarkdown = void 0;

var _jsYaml = require("js-yaml");

var _marked = _interopRequireDefault(require("marked"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const separate = jekyllMarkdown => {
  const re = /^---s*$\r?\n/m;
  const m1 = jekyllMarkdown.match(re);
  if (m1 === null) return {
    markdown: jekyllMarkdown,
    yaml: ''
  };
  const s1 = jekyllMarkdown.substring(m1.index + m1[0].length);
  const m2 = s1.match(re);
  if (m2 === null) return {
    markdown: jekyllMarkdown,
    yaml: ''
  };
  const yaml = s1.substring(0, m2.index);
  const markdown = s1.substring(m2.index + m2[0].length);
  return {
    markdown,
    yaml
  };
};

exports.separate = separate;

const compileMarkdown = (markdown, options) => {
  return (0, _marked.default)(markdown, options);
};

exports.compileMarkdown = compileMarkdown;

const parseYaml = yaml => {
  return (0, _jsYaml.safeLoad)(yaml);
};

exports.parseYaml = parseYaml;

const parse = (jekyllMarkdown, options) => {
  const {
    yaml,
    markdown
  } = separate(jekyllMarkdown);
  const parsedYaml = parseYaml(yaml);
  const compileMarkdownOptions = typeof options === 'undefined' ? void 0 : options.compileMarkdownOptions;
  const html = compileMarkdown(markdown, compileMarkdownOptions);
  return {
    html,
    markdown,
    parsedYaml,
    yaml
  };
};

exports.parse = parse;